@@ -2,8 +2,8 @@
 //  authenticate.cpp -- Function to authenticate to Bloomberg backend
 //
 //  Copyright (C) 2013      Whit Armstrong
-//  Copyright (C) 2015-2024 Whit Armstrong and Dirk Eddelbuettelp
-//  Copyright (C) 2019-2024 Whit Armstrong, Dirk Eddelbuettel and Alfred Kanzler
+//  Copyright (C) 2015-2025 Whit Armstrong and Dirk Eddelbuettelp
+//  Copyright (C) 2019-2025 Whit Armstrong, Dirk Eddelbuettel and Alfred Kanzler
 //
 //  This file is part of Rblpapi
 //
@@ -20,7 +20,7 @@
 //  You should have received a copy of the GNU General Public License
 //  along with Rblpapi.  If not, see <http://www.gnu.org/licenses/>.
 
-
+#if defined(HaveBlp)
 #include <string>
 #include <blpapi_defs.h>
 #include <blpapi_element.h>
@@ -31,7 +31,6 @@
 #include <blpapi_session.h>
 #include <blpapi_event.h>
 #include <blpapi_message.h>
-#include <Rcpp.h>
 #include <finalizers.h>
 #include <blpapi_utils.h>
 
@@ -179,18 +178,26 @@ Identity* authenticateWithApp(SEXP con_) {
     }
     return identity_p;
 }
+#else
+#include <Rcpp/Lightest>
+#endif
 
 // Simpler interface
 //
 // [[Rcpp::export]]
-SEXP authenticate_Impl(SEXP con_, SEXP uuid_, SEXP ip_address_, SEXP is_auth_id_,
-                       SEXP app_name_) {
+SEXP authenticate_Impl(SEXP con_, SEXP uuid_, SEXP ip_address_, SEXP is_auth_id_, SEXP app_name_) {
+#if defined(HaveBlp)
     Identity* identity_p = NULL;
     if (uuid_ == R_NilValue) {
         identity_p = authenticateWithApp(con_);
     } else {
         identity_p = authenticateWithId(con_, uuid_, ip_address_, is_auth_id_, app_name_);
     }
-    if(identity_p == NULL) { Rcpp::stop("Identity pointer is null\n"); }
+    if (identity_p == NULL) {
+        Rcpp::stop("Identity pointer is null\n");
+    }
     return createExternalPointer<Identity>(identity_p, identityFinalizer, "blpapi::Identity*");
+#else // ie no Blp
+    return R_NilValue;
+#endif
 }
