@@ -2,7 +2,7 @@
 //  bdp.cpp -- "Bloomberg Data Point" query function for the BLP API
 //
 //  Copyright (C) 2013         Whit Armstrong
-//  Copyright (C) 2015 - 2024  Whit Armstrong and Dirk Eddelbuettel
+//  Copyright (C) 2015 - 2025  Whit Armstrong and Dirk Eddelbuettel
 //
 //  This file is part of Rblpapi
 //
@@ -19,10 +19,8 @@
 //  You should have received a copy of the GNU General Public License
 //  along with Rblpapi.  If not, see <http://www.gnu.org/licenses/>.
 
-
+#if defined(HaveBlp)
 // compare to RefDataExample.cpp
-
-
 #include <iostream>
 #include <vector>
 #include <string>
@@ -32,7 +30,6 @@
 #include <blpapi_event.h>
 #include <blpapi_message.h>
 #include <blpapi_element.h>
-#include <Rcpp.h>
 #include <blpapi_utils.h>
 
 using BloombergLP::blpapi::Session;
@@ -47,14 +44,27 @@ using BloombergLP::blpapi::Name;
 void getBDPResult(Event& event, Rcpp::List& res, const std::vector<std::string>& securities, const std::vector<std::string>& colnames, const std::vector<RblpapiT>& rtypes, bool verbose) {
     MessageIterator msgIter(event);
     if (!msgIter.next()) {
-        throw std::logic_error("Not a valid MessageIterator.");
+        Rcpp::stop("Not a valid MessageIterator.");
     }
     Message msg = msgIter.message();
     Element response = msg.asElement();
     if (verbose) response.print(Rcpp::Rcout);
     if (std::strcmp(response.name().string(),"ReferenceDataResponse")) {
-        throw std::logic_error("Not a valid ReferenceDataResponse.");
+        Rcpp::stop("Not a valid ReferenceDataResponse.");
     }
+
+    const Name responseError("responseError");
+    if (response.hasElement(responseError)) {
+        Element errorElement = msg.getElement(responseError);
+        std::string errMsg("");
+        const Name messageTag("message");
+        if (errorElement.hasElement(messageTag)) {
+            errMsg = errorElement.getElementAsString(messageTag);
+        }
+        Rcpp::Rcerr << "REQUEST FAILED: " <<  errorElement << std::endl;
+        Rcpp::stop("bdp result: a responseError was received with message: (" + errMsg + ")");
+    }
+
     Element securityData = response.getElement(Name{"securityData"});
 
     for (size_t i = 0; i < securityData.numValues(); ++i) {
@@ -63,20 +73,23 @@ void getBDPResult(Event& event, Rcpp::List& res, const std::vector<std::string>&
 
         // check that the seqNum matches the order of the securities vector (it's a grave error to screw this up)
         if(securities[row_index].compare(this_security.getElementAsString(Name{"security"}))!=0) {
-            throw std::logic_error("mismatched Security sequence, please report a bug.");
+            Rcpp::stop("mismatched Security sequence, please report a bug.");
         }
         Element fieldData = this_security.getElement(Name{"fieldData"});
         for(size_t j = 0; j < fieldData.numElements(); ++j) {
             Element e = fieldData.getElement(j);
             auto col_iter = std::find(colnames.begin(), colnames.end(), e.name().string());
             if (col_iter == colnames.end()) {
-                throw std::logic_error(std::string("column is not expected: ") + e.name().string());
+                Rcpp::stop(std::string("column is not expected: ") + e.name().string());
             }
             size_t col_index = std::distance(colnames.begin(),col_iter);
             populateDfRow(res[col_index],row_index,e,rtypes[col_index]);
         }
     }
 }
+#else
+#include <Rcpp/Lightest>
+#endif
 
 // Simpler interface with std::vector<std::string> thanks to Rcpp::Attributes
 //
@@ -84,8 +97,10 @@ void getBDPResult(Event& event, Rcpp::List& res, const std::vector<std::string>&
 Rcpp::List bdp_Impl(SEXP con_, std::vector<std::string> securities, std::vector<std::string> fields,
                     SEXP options_, SEXP overrides_, bool verbose, SEXP identity_) {
 
+#if defined(HaveBlp)
+
     // via Rcpp Attributes we get a try/catch block with error propagation to R "for free"
-    Session* session = 
+    Session* session =
         reinterpret_cast<Session*>(checkExternalPointer(con_, "blpapi::Session*"));
 
     // get the field info
@@ -101,7 +116,7 @@ Rcpp::List bdp_Impl(SEXP con_, std::vector<std::string> securities, std::vector<
     if (!session->openService(rdsrv.c_str())) {
         Rcpp::stop("Failed to open " + rdsrv);
     }
-    
+
     Service refDataService = session->getService(rdsrv.c_str());
     Request request = refDataService.createRequest("ReferenceDataRequest");
     createStandardRequest(request, securities, fields, options_, overrides_);
@@ -124,4 +139,8 @@ Rcpp::List bdp_Impl(SEXP con_, std::vector<std::string> securities, std::vector<
         if (event.eventType() == Event::RESPONSE) { break; }
     }
     return res;
+
+#else // ie no Blp
+    return Rcpp::List();
+#endif
 }
