@@ -1,7 +1,7 @@
 //
 //  lookup.cpp -- symbol look-up
 //
-//  Copyright (C) 2017 - 2024  Dirk Eddelbuettel and Kevin Jin
+//  Copyright (C) 2017 - 2025  Dirk Eddelbuettel and Kevin Jin
 //
 //  This file is part of Rblpapi
 //
@@ -18,19 +18,17 @@
 //  You should have received a copy of the GNU General Public License
 //  along with Rblpapi.  If not, see <http://www.gnu.org/licenses/>.
 
-#include <blpapi_session.h>
+#if defined(HaveBlp)
 
+#include <blpapi_session.h>
 #include <blpapi_event.h>
 #include <blpapi_message.h>
 #include <blpapi_element.h>
 #include <blpapi_name.h>
 #include <blpapi_request.h>
-
 #include <iostream>
 #include <vector>
 #include <string>
-
-#include <Rcpp.h>
 #include <blpapi_utils.h>
 
 namespace bbg = BloombergLP::blpapi;	// shortcut to not globally import both namespace
@@ -51,7 +49,7 @@ void processMessage(bbg::Message &msg, InstrumentListResults &matches, const boo
     bbg::Element response = msg.asElement();
     if (verbose) response.print(Rcpp::Rcout);
     if (std::strcmp(response.name().string(),"InstrumentListResponse")) {
-        throw std::logic_error("Not a valid InstrumentListResponse.");
+        Rcpp::stop("Not a valid InstrumentListResponse.");
     }
 
     bbg::Element data = response.getElement(bbg::Name{"results"});
@@ -84,6 +82,9 @@ void processResponseEvent(bbg::Event &event, InstrumentListResults &matches, con
         processMessage(msg, matches, verbose);
     }
 }
+#else
+#include <Rcpp/Lightest>
+#endif
 
 // [[Rcpp::export]]
 Rcpp::DataFrame lookup_Impl(SEXP con,
@@ -92,7 +93,7 @@ Rcpp::DataFrame lookup_Impl(SEXP con,
                             std::string languageOverride="LANG_OVERRIDE_NONE",
                             int maxResults=20,
                             bool verbose=false) {
-
+#if defined(HaveBlp)
     // via Rcpp Attributes we get a try/catch block with error propagation to R "for free"
     bbg::Session* session =
         reinterpret_cast<bbg::Session*>(checkExternalPointer(con,"blpapi::Session*"));
@@ -140,4 +141,7 @@ Rcpp::DataFrame lookup_Impl(SEXP con,
 
     return Rcpp::DataFrame::create(Rcpp::Named("security") = matches.security,
                                    Rcpp::Named("description") = matches.description);
+#else // ie no Blp
+    return Rcpp::DataFrame();
+#endif
 }
